/*****************************************************************/
/* FILE:        	w1assets.sas                             */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Tiago Ribeiro                            */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Code Wave 1 assets and income            */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/

%global thisfile;
%let lastfile=&thisfile;
%let thisfile=w1assets;
proc printto log="&thisfile..log" print="&thisfile..lst" new; run;

%include "~/ribeiro/datagen/header.inc";
options ls=120;


%macro h;

x zcat "&rawc1/bhh21.ssd01.Z"  > "&local/bhh21.ssd01";
*x zcat "&rawc1/bhp21.ssd01.Z"  > "&local/bhp21.ssd01";
*x zcat "&rawc1/bop21.ssd01.Z"  > "&local/bop21.ssd01";
*x zcat "&rawc1/br21.ssd01.Z"   > "&local/br21.ssd01";

proc contents data=local.bhh21;
*proc contents data=local.bhp21;
*proc contents data=local.bop21;
*proc contents data=local.br21;



data w1assets;
    set local.bhh21;
*    keep hhid v1720  v1721 v1721c;
run;

data local8.w1ast0;
    set w1assets;
    run;
    
x /bin/rm  "&local/bhh21.ssd01";
*x /bin/rm  "&local/bhp21.ssd01";
*x /bin/rm  "&local/bop21.ssd01";
*x /bin/rm  "&local/br21.ssd01";
    
%mend;
*%h;

data w1assets;
    set local8.w1ast0;
    run;

    
%include cbrak1; *macro for coding all assets;
%vtic(w1assets);


*%macro cbrak1(type,lead,amt,cat,listbp,excl,ncat);


%cbrak1(rlst,v1720,v1721,v1721c,5000 50000 150000,9999999,);

data w1assets;
    set w1assets;
    if v1725=0 then ltrns=5;
    else if v1725>0 or v1725c in(0,1,2,3,4,5,6) then ltrns=1;
run;

proc freq;
    tables v1725c*ltrns /missing;
    run;

    
%cbrak1(trns,ltrns,v1725,v1725c,2000 10000 25000,9999999,);
%cbrak1(bsns,v1729,v1730,v1730c,10000 50000 500000,9999999,);
%cbrak1(ira,v1734 ,v1735,v1735c,5000 25000  50000 100000,9999999,);
%cbrak1(stck,v1743,v1744,v1744c,5000 25000 100000 500000,9999999,);
%cbrak1(chck,v1749,v1750,v1750c,1000  5000  10000  50000,9999999,);
%cbrak1(cd,v1755  ,v1756,v1756c,1000  5000  10000  50000,9999999,);
%cbrak1(bond,v1761,v1762,v1762c,5000 25000 100000 500000,9999999,);

data w1assets;
    set w1assets;
    if v1778>=0 then vtrust=1;
    if v1780>=0 then vtrusto=1;
    run;
        

    proc freq;
        tables v1775*vtrust*v1779*vtrusto / list missing;
        run;


/*
Don't code trust for now since most of the respondents
already reported the value of the trust assets before 

v1775 
v1778 
v1779
v1780

                                                    Cumulative  Cumulative
V1775  VTRUST  V1779  VTRUSTO   Frequency  Percent   Frequency    Percent
--------------------------------------------------------------------------
    .       .      .        .          74     1.2           74        1.2
    D       .      .        .          26     0.4          100        1.7
    R       .      .        .          52     0.9          152        2.5
    1       .      D        .           5     0.1          157        2.6
    1       .      R        .           5     0.1          162        2.7
    1       .      1        .         166     2.7          328        5.4
    1       .      2        .           7     0.1          335        5.5
    1       .      5        .          15     0.2          350        5.8
    1       1      D        .           1     0.0          351        5.8
    1       1      1        .         238     3.9          589        9.7
    1       1      2        .           2     0.0          591        9.8
    1       1      2        1           8     0.1          599        9.9
    1       1      5        .          18     0.3          617       10.2
    5       .      .        .        5430    89.8         6047      100.0

*/
        
%cbrak1(othr,v1782,v1783,v1783c,2000 10000 25000,9999999,);
%cbrak1(debt,v1787,v1788,v1788c,2000 10000 25000,9999999,);

%cbrak1(lps1,v1796,v1796,v1796c,3000,9999999,);
%cbrak1(lps2,v1802,v1802,v1802c,2000,9999999,);
%cbrak1(lps3,v1808,v1808,v1808c,2000,9999999,);


data w1assets;
    set w1assets;
    if v1648=0 then ltinc=0;
    if v1648>0 and v1648<9999997 then ltinc=1;
    if v1648>=9999997 or v1648 in(.,.D,.R) then ltinc=2;
    if v1648 in(0,.,.D,.R) then v1648=.;
    if v1648c=0 then v1648c=.; 

run;

proc freq data=w1assets;
    tables ltinc*v1648*v1648c/list missing;
run;

data w1assets;
    set w1assets;
    ltinc=1;
run;

proc freq data=w1assets;
    tables ltinc*v1648*v1648c/list missing;
run;

%cbrak1(tinc,ltinc,v1648,v1648c,5000 10000 20000 30000 50000 75000 100000,9999990,);
data w1assets;
    set w1assets;
    drop ltinc;
run;

proc freq;
    tables v1029*v1067*v1086*v1087*v1088*v1091*v1092 /list missing;
    run;
    
data w1assets;
    set w1assets;

    housv=(v1099>0 and v1099<99999990);
    
    if v1029 eq 3 then do; *mob home;
        l_mob=9;
        l_hous=5;
        if v1067 in(1,2,3) then l_mob=1;
        if v1067 in(4,7) then l_mob=5;
        end;
    else if v1029 not in(3,.,.R,.D) then do; *not mob home;
        l_mob=5;
        l_hous=9;
        if v1086=1 then do; *Live farm;
            if v1087=1 or v1088=1 then l_hous=1;
            else if v1087 in(3,7) then l_hous=5;
            end;
        else do;
            if v1091=1 then l_hous=1;
            if v1091 in(2,7) then l_hous=5;
            end;
        end;
    else do;
        * NOTE: DK/RF to type of house and/or RF/DK to own house;
        * will be treated as missing ownership and therefore imputed;
        l_mob=5;
        l_hous=9;
        end;
    
    if v1029 ne . then do;
        mobhome1=(v1029=3);
        singfam1=(v1029=1);
        duplex1=(v1029=2);
        aptment1=(v1029 in(4,5));
        othhous1=(v1029=7);
        end;
    
    mobsite1 = (mobhome1=1 and v1067 in(1,2));   
    ownbldg1=(v1092=1);
    farmlnd1=(v1087=1);
    farm1=(v1086=1);

    if l_mob=9 then l_mob=.;
    if l_hous=9 then l_hous=.;

    a_mob=v1099; c_mob=v1099c;
    a_hous=v1099; c_hous=v1099c;

    if l_mob=5 then do;
        a_mob=0; c_mob=0;
        end;
    if l_hous=5 then do;
        a_hous=0; c_hous=0;
        end;
    
run;


proc freq;
    tables l_mob l_hous housv l_mob*l_hous*housv*v1029*v1067*v1086*v1087*v1088*v1091*v1099c  /list missing;
    run;

%cbrak1(mobh,l_mob,a_mob,c_mob,50000 100000 200000,99999990,);
%cbrak1(hous,l_hous,a_hous,c_hous,50000 100000 200000,99999990,);


 proc freq;
  tables d_hous1*d_mobh1*v1121*v1127 /list missing;
run;

data w1assets;
    set w1assets;

    if
        (d_hous1=. and d_mobh1=0) or
        (d_hous1=0 and d_mobh1=.) or
        (d_hous1=0 and d_mobh1=0)  then do;
        
        d_mort1=0;
        d_2mrt1=0;
        dimort1=0;
        di2mrt1=0;
        a_mort1=0;
        a_2mrt1=0;
        i_mort1=0;
        i_2mrt1=0;
        c_mort1=0;
        c_2mrt1=0;
        end;
        
    if
        (d_hous1=1 and d_mobh1=0) or
        (d_hous1=0 and d_mobh1=1) then do;
        
        if v1121 in(1,3) then do;
            d_mort1=1;
            dimort1=0;
            c_mort1=1;
            if v1126 not in(.,.R,.D) then do;
                a_mort1=v1126;
                i_mort1=0;
                end;
            if v1126  in(.,.R,.D) then do;
                a_mort1=.;
                i_mort1=1;
                end;

            if v1127 in(1,3) then do;
                d_2mrt1=1;
                di2mrt1=0;
                c_2mrt1=1;
                if v1131 not in(.,.R,.D) then do;
                    a_2mrt1=v1126;
                    i_2mrt1=0;
                    end;
                if v1131  in(.,.R,.D) then do;
                    a_2mrt1=.;
                    i_2mrt1=1;
                    end;
                end;
            
            if v1127 in(5) then do;            
                d_2mrt1=0;
                di2mrt1=0;
                a_2mrt1=0;
                i_2mrt1=0;
                c_2mrt1=0;
                end;
            
            if v1127 in(.,.R,.D) then do;            
                if v1131 not in(.,.R,.D) then do;
                    d_2mrt1=1;
                    di2mrt1=0;
                    a_2mrt1=v1131;
                    i_2mrt1=0;
                    c_2mrt1=1;
                    end;
                else if v1131  in(.,.R,.D) then do;
                    d_2mrt1=.;
                    di2mrt1=1;
                    a_2mrt1=.;
                    i_2mrt1=1;
                    c_2mrt1=2;
                    end;
                end;
            
            end;

        else if v1121 in(5) then do;
            
            d_mort1=0;
            dimort1=0;
            a_mort1=0;
            i_mort1=0;
            c_mort1=0;
            
            d_2mrt1=0;
            di2mrt1=0;
            a_2mrt1=0;
            i_2mrt1=0;
            c_2mrt1=0;

            end;

        else if v1121 in(.,.R,.D) then do;
            
            d_2mrt1=0;
            di2mrt1=0;
            a_2mrt1=0;
            i_2mrt1=0;
            c_2mrt1=0;

            if v1126 not in(.,.R,.D) then do;
                d_mort1=1;
                dimort1=0;
                a_mort1=v1126;
                i_mort1=0;
                c_mort1=1;
                end;
            else if v1126  in(.,.R,.D) then do;
                d_mort1=.;
                dimort1=1;
                a_mort1=.;
                i_mort1=1;
                c_mort1=2;
                end;
            end;
        end;
run;


 proc freq;
  tables d_hous1*d_mobh1*d_mort1*dimort1*i_mort1*c_mort1*d_2mrt1*di2mrt1*i_2mrt1*c_2mrt1 /list missing;
run;

 proc freq;
  tables d_hous1*d_mobh1*v1132 /list missing;
run;

data w1assets;
    set w1assets;
    if
        (d_hous1=. and d_mobh1=0) or
        (d_hous1=0 and d_mobh1=.) or
        (d_hous1=0 and d_mobh1=0)  then do;
        
        d_loan1=0;
        diloan1=0;
        a_loan1=0;
        i_loan1=0;
        c_loan1=0;
        end;
    
    if
        (d_hous1=1 and d_mobh1=0) or
        (d_hous1=0 and d_mobh1=1) then do;
        
        if v1132 in(1,3) then do;
            d_loan1=1;
            diloan1=0;
            c_loan1=1;
            if v1135 not in(.,.R,.D) then do;
                a_loan1=v1135;
                i_loan1=0;
                end;
            if v1135  in(.,.R,.D) then do;
                a_loan1=.;
                i_loan1=1;
                end;
            end;
        
        else if v1132 in(5) then do;
            d_loan1=0;
            diloan1=0;
            a_loan1=0;
            i_loan1=0;
            c_loan1=0;            
            end;

        else if v1132 in(.,.R,.D) then do;
            if v1135 not in(.,.R,.D) then do;
                d_loan1=1;
                diloan1=0;
                a_loan1=v1135;
                i_loan1=0;
                c_loan1=1;
                end;
            else if v1135  in(.,.R,.D) then do;
                d_loan1=.;
                diloan1=1;
                a_loan1=.;
                i_loan1=1;
                c_loan1=2;
                end;
            end;
        end;
    

run;


proc freq;
    tables d_hous1*d_mobh1*d_loan1*diloan1*i_loan1*c_loan1 /list missing;
run;


   
data w1assets;
   set w1assets;
   format   
      c_rlst1 rlst1f.
      c_bsns1 bsns1f.
      c_ira1   ira1f.
      c_stck1 stck1f.
      c_bond1 bond1f.
      c_cd1     cd1f.
      c_chck1 chck1f.
      c_trns1 trns1f.
      c_othr1 othr1f.
      c_debt1 debt1f.

      c_hous1 hous1f.
      c_mobh1 mobh1f.
      c_mort1 mort1f.
      c_2mrt1 mort1f.
      c_loan1 mort1f.
      c_tinc1 tinc1f.
     ;
   run;



data w1assets;
    set w1assets;
       
   numrom1=v1081;
   
   nhood1=v1085;
   if nhood1 not in(8,9,.,.R,.D) then do; 
       hoodex1=(v1085=1);
       hoodvg1=(v1085=2);
       hoodgd1=(v1085=3);
       hoodfr1=(v1085=4);
       hoodpr1=(v1085=5);
       end;

   hcond1=v1083;
   if hcond1 not in(8,9,.,.R,.D) then do; 
       condex1=(v1083=1);
       condvg1=(v1083=2);
       condgd1=(v1083=3);
       condfr1=(v1083=4);
       condpr1=(v1083=5);
       end;



   *****************************************************************;
   * Label variables ;
   *****************************************************************;
   
   
   label
       
       ownbldg1='own entire bldg w1'
       singfam1='single family house w1'
       duplex1='duplex house w1'
       mobhome1='mobile home w1'
       mobsite1='mob home and site w1'
       othhous1='other house type w1'
       aptment1='apartment w1'

       numrom1='number of rooms w1'

       farm1='live on farm w1'
       farmlnd1='own farm/land w1'

       nhood1='neighborhood condition w1'
       hcond1='house condition w1'
       
       hoodex1='neighborhood exc w1'
       hoodvg1='neighborhood v good w1'
       hoodgd1='neighborhood good w1'
       hoodfr1='neighborhood fair w1'
       hoodpr1='neighborhood poor w1'
       
       condex1='house condition exc w1'
       condvg1='house condition v gd w1'
       condgd1='house condition good w1'
       condfr1='house condition fair w1'
       condpr1='house condition poor w1'
       ;
   

   
   %label(rlst,w1);
   %label(trns,w1);
   %label(bsns,w1);
   %label(ira,w1);
   %label(stck,w1);
   %label(chck,w1);
   %label(cd,w1);
   %label(bond,w1);
   %label(othr,w1);
   %label(debt,w1);
   %label(mobh,w1);
   %label(hous,w1);
   %label(mort,w1);
   %label(2mrt,w1);
   %label(loan,w1);
   %label(lps1,w1);
   %label(lps2,w1);
   %label(lps3,w1);
   %label(tinc,w1);

   drop  L_HOUS  L_MOB  housv VTRUST VTRUSTO
       A_HOUS A_MOB C_HOUS C_MOB  LTRNS        
       IN1 IN2       
;

run;


%vtoc(w1assets);

proc freq;
   tables %list12(c_,1);
proc means;  
    var %list12(d_,1);;
    var %list12(di,1);;
    var %list12(a_,1);;
    var %list12(i_,1);;
   

data local8.w1assets;
   set w1assets;
   keep  hhid dsubhh dpn_fin;
   keep %include "&thisfile..vars";;
run;
        
proc means;
proc contents;
    
x '/usr/xpg4/bin/rm code_e';   
x '/usr/xpg4/bin/rm code_cat';   

 

   /****************************************************/ 
   /*****************End of File************************/ 
   /****************************************************/ 

   %let thisfile=&lastfile;
   proc printto log="&thisfile..log" print="&thisfile..lst"; run;

   /****************************************************/ 
   /****************************************************/ 
   /****************************************************/ 
