/*****************************************************************/
/* FILE:        	imp_health.sas                           */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Tiago Ribeiro                            */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Minor imputation of some health condition*/
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/

%include "&impdir/impcat_macro.sas";

data allwv0 allwv1;
    set allwv;
    if inw1 then output allwv0;
    else output allwv1;
run;

data map;
    input var1 var2  map;
    cards;
    1 0 0
    0 1 1
    1 1 2
        ;
run;    

%macro maps;   
    %let n=1;
    %let v=%scan(&impv,&n);
    %do %while(&v ne %str());
        data &v;
            set map;
            rename map=&v;
        run;
        %let n=%eval(&n+1);
    %let v=%scan(&impv,&n);
    %end;
%mend;


%let seed=1;
%let cntrlv=;
%let w=1;
%let p=;
%let impv=
    &p.cancer&w
    &p.heart&w
    &p.stroke&w
    &p.highbp&w
    &p.lung&w
    &p.arthrt&w
    &p.diabet&w
    ;
%let p=_;
%let impvn=
    &p.cancer&w
    &p.heart&w
    &p.stroke&w
    &p.highbp&w
    &p.lung&w
    &p.arthrt&w
    &p.diabet&w
    ;
%let mapd=&impv;

data allwv0;
    set allwv0;
    array tmp{*} &impv;
    do i=1 to dim(tmp);
        if tmp{i}=. then tmp{i}=2;
        end;
    drop i;

    hlthch1=1*hlthbet1+2*hlthsam1+3*hlthwrs1;
    if hlth1=. then hlth1=6;
    if hlthch1=. then hlthch1=4;

run;
%maps;

   
%impcat(allwv0,&impv,&impvn,&mapd,&cntrlv,&seed);
data allwv0;
    set allwv0;
    array t1{*} &impv;
    array t2{*} &impvn;
    do i=1 to dim(t1);
        t1{i}=t2{i};
        end;
    drop i &impvn;
run;

%let seed=2;
%let cntrlv=;
%let w=1;
%let p=;
%let impv=
    &p.psych&w
    &p.fall&w
    &p.hipfrc&w
    &p.incont&w
    &p.depres&w
    &p.cogim&w
    &p.smokev
    &p.smoknow&w
    ;
%let p=_;
%let impvn=
    &p.psych&w
    &p.fall&w
    &p.hipfrc&w
    &p.incont&w
    &p.depres&w
    &p.cogim&w
    &p.smokev
    &p.smoknow&w
    ;
%let mapd=&impv;

data allwv0;
    set allwv0;
    array tmp{*} &impv;
    do i=1 to dim(tmp);
        if tmp{i}=. then tmp{i}=2;
        end;
    drop i;
run;
%maps;

proc freq data=allwv0;
    tables &impv / missing;
    run;
   
%impcat(allwv0,&impv,&impvn,&mapd,&cntrlv,&seed);
data allwv0;
    set allwv0;
    array t1{*} &impv;
    array t2{*} &impvn;
    do i=1 to dim(t1);
        t1{i}=t2{i};
        end;
    drop i &impvn;
run;



data hlth1;
    input var1 var2 var3 var4 var5 hlth1;
    cards;
    1 0 0 0 0 1
    0 1 0 0 0 2
    0 0 1 0 0 3
    0 0 0 1 0 4
    0 0 0 0 1 5
    1 1 1 1 1 6
        ;
run;

data hlthch1;
    input var1 var2 var3 hlthch1;
    cards;
    1 0 0 1
    0 1 0 2
    0 0 1 3
    1 1 1 4
        ;
run;


%let seed=3;
%let p=;
%let cntrlv=
    &p.cancer&w
    &p.heart&w
    &p.stroke&w
    &p.psych&w
    &p.fall&w
    &p.hipfrc&w
    &p.incont&w
    &p.depres&w
    ;

%let impv=hlth1 hlthch1;
%let impvn=_hlth1 _hlthch1;
%let mapd=hlth1 hlthch1;

%impcat(allwv0,&impv,&impvn,&mapd,&cntrlv,&seed);
data allwv0;
    set allwv0;
    array t1{*} &impv;
    array t2{*} &impvn;
    do i=1 to dim(t1);
        t1{i}=t2{i};
        end;
    drop i &impvn hlthch1;

    hlthbet1=(hlthch1=1);
    hlthsam1=(hlthch1=2);
    hlthwrs1=(hlthch1=3);
run;


data allwv;
    set allwv0 allwv1;
run;


/* Wave 2 */

data allwv0 allwv1;
    set allwv;
    if inw2 or exitw2 then output allwv0;
    else output allwv1;
run;


%let seed=4;
%let cntrlv=;
%let w=2;
%let p=;
%let impv=
    &p.cancer&w
    &p.heart&w
    &p.stroke&w
    &p.highbp&w
    &p.lung&w
    &p.arthrt&w
    &p.diabet&w
    ;
%let p=_;
%let impvn=
    &p.cancer&w
    &p.heart&w
    &p.stroke&w
    &p.highbp&w
    &p.lung&w
    &p.arthrt&w
    &p.diabet&w
   ;
%let mapd=&impv;

data allwv0;
    set allwv0;
    array tmp{*} &impv;
    do i=1 to dim(tmp);
        if tmp{i}=. then tmp{i}=2;
        end;
    drop i;

    hlthch2=1*hlthbet2+2*hlthsam2+3*hlthwrs2;
    if hlth2   =. then hlth2=6;
    if hlthch2 =. then hlthch2=4;
    if numadl2 =. then numadl2=7;
    if numiadl2=. then numiadl2=6;

run;
%maps;

proc freq data=allwv0;
    where exitw2;
    tables &impv hlth2 hlthch2  numadl2 numiadl2/ missing;
run;

    
%impcat(allwv0,&impv,&impvn,&mapd,&cntrlv,&seed);
data allwv0;
    set allwv0;
    array t1{*} &impv;
    array t2{*} &impvn;
    do i=1 to dim(t1);
        t1{i}=t2{i};
        end;
    drop i &impvn;
run;

%let seed=5;
%let cntrlv=;
%let w=2;
%let p=;
%let impv=
    &p.psych&w
    &p.fall&w
    &p.hipfrc&w
    &p.incont&w
    &p.depres&w
    &p.cogim&w
    &p.smoknow&w
    &p.drnknow&w
    ;
%let p=_;
%let impvn=
    &p.psych&w
    &p.fall&w
    &p.hipfrc&w
    &p.incont&w
    &p.depres&w
    &p.cogim&w
    &p.smoknow&w 
    &p.drnknow&w
   ;
%let mapd=&impv;

data allwv0;
    set allwv0;
    array tmp{*} &impv;
    do i=1 to dim(tmp);
        if tmp{i}=. then tmp{i}=2;
        end;
    drop i;
run;
%maps;

proc freq data=allwv0;
    where exitw2;
    tables &impv / missing;
run;

    
%impcat(allwv0,&impv,&impvn,&mapd,&cntrlv,&seed);
data allwv0;
    set allwv0;
    array t1{*} &impv;
    array t2{*} &impvn;
    do i=1 to dim(t1);
        t1{i}=t2{i};
        end;
    drop i &impvn;
run;


data hlth2;
    input var1 var2 var3 var4 var5 hlth2;
    cards;
    1 0 0 0 0 1
    0 1 0 0 0 2
    0 0 1 0 0 3
    0 0 0 1 0 4
    0 0 0 0 1 5
    1 1 1 1 1 6
        ;
run;
data hlthch2;
    input var1 var2 var3 hlthch2;
    cards;
    1 0 0 1
    0 1 0 2
    0 0 1 3
    1 1 1 4
        ;
run;
data numadl2;
    input var0 var1 var2 var3 var4 var5 v6 numadl2;
    cards;
    1 0 0 0 0 0 0 0
    0 1 0 0 0 0 0 1
    0 0 1 0 0 0 0 2
    0 0 0 1 0 0 0 3
    0 0 0 0 1 0 0 4
    0 0 0 0 0 1 0 5
    0 0 0 0 0 0 1 6
    1 1 1 1 1 1 1 7
        ;
run;
data numiadl2;
    input var0 var1 var2 var3 var4 var5 numiadl2;
    cards;
    1 0 0 0 0 0 0
    0 1 0 0 0 0 1
    0 0 1 0 0 0 2
    0 0 0 1 0 0 3
    0 0 0 0 1 0 4
    0 0 0 0 0 1 5
    1 1 1 1 1 1 6
        ;
run;

%let seed=6;
%let p=;
%let cntrlv=
    &p.cancer&w
    &p.heart&w
    &p.stroke&w
    &p.psych&w
    &p.fall&w
    &p.hipfrc&w
    &p.incont&w
    &p.depres&w
    ;
%let impv=hlth2 hlthch2;
%let impvn=_hlth2 _hlthch2;
%let mapd=hlth2 hlthch2;


%impcat(allwv0,&impv,&impvn,&mapd,&cntrlv,&seed);
data allwv0;
    set allwv0;
    array t1{*} &impv;
    array t2{*} &impvn;
    do i=1 to dim(t1);
        t1{i}=t2{i};
        end;
    drop i &impvn ;
run;


%let seed=7;
%let impv=numadl2 numiadl2;
%let impvn=_numadl2 _numiadl2;
%let mapd=numadl2 numiadl2;
%impcat(allwv0,&impv,&impvn,&mapd,&cntrlv,&seed);

%let noexit=highbp2 arthrt2 diabet2 psych2 depres2 smoknow2 drnknow2 hlth2 hlthch2;
data allwv0;
    set allwv0;
    array t1{*} &impv;
    array t2{*} &impvn;
    do i=1 to dim(t1);
        t1{i}=t2{i};
        end;
    drop i &impvn;

    array t3{*} &noexit;
    do i=1 to dim(t3);
        if exitw2=1 then t3{i}=.;
        end;

    if hlthch2 ne . then do;
        hlthbet2=(hlthch2=1);
        hlthsam2=(hlthch2=2);
        hlthwrs2=(hlthch2=3);
        end;
    drop hlthch2;    
run;

data allwv;
    set allwv0 allwv1;
run;


/* Wave 3 */

data allwv0 allwv1;
    set allwv;
    if inw3 or exitw3 then output allwv0;
    else output allwv1;
run;


%let seed=8;
%let cntrlv=;
%let w=3;
%let p=;
%let impv=
    &p.cancer&w
    &p.heart&w
    &p.stroke&w
    &p.highbp&w
    &p.lung&w
    &p.arthrt&w
    &p.diabet&w
    ;
%let p=_;
%let impvn=
    &p.cancer&w
    &p.heart&w
    &p.stroke&w
    &p.highbp&w
    &p.lung&w
    &p.arthrt&w
    &p.diabet&w
   ;
%let mapd=&impv;

data allwv0;
    set allwv0;
    array tmp{*} &impv;
    do i=1 to dim(tmp);
        if tmp{i}=. then tmp{i}=2;
        end;
    drop i;

    hlthch3=1*hlthbet3+2*hlthsam3+3*hlthwrs3;
    if hlth3   =. then hlth3=6;
    if hlthch3 =. then hlthch3=4;
    if numadl3 =. then numadl3=7;
    if numiadl3=. then numiadl3=6;

run;
%maps;

proc freq data=allwv0;
    where exitw3;
    tables &impv hlth3 hlthch3  numadl3 numiadl3/ missing;
run;

    
%impcat(allwv0,&impv,&impvn,&mapd,&cntrlv,&seed);
data allwv0;
    set allwv0;
    array t1{*} &impv;
    array t2{*} &impvn;
    do i=1 to dim(t1);
        t1{i}=t2{i};
        end;
    drop i &impvn;
run;

%let seed=9;
%let cntrlv=;
%let w=3;
%let p=;
%let impv=
    &p.psych&w
    &p.fall&w
    &p.hipfrc&w
    &p.incont&w
    &p.depres&w
    &p.cogim&w
    &p.smoknow&w
    &p.drnknow&w
    ;
%let p=_;
%let impvn=
    &p.psych&w
    &p.fall&w
    &p.hipfrc&w
    &p.incont&w
    &p.depres&w
    &p.cogim&w
    &p.smoknow&w 
    &p.drnknow&w
   ;
%let mapd=&impv;

data allwv0;
    set allwv0;
    array tmp{*} &impv;
    do i=1 to dim(tmp);
        if tmp{i}=. then tmp{i}=2;
        end;
    drop i;
run;

%maps;

proc freq data=allwv0;
    where exitw3;
    tables &impv / missing;
run;

    
%impcat(allwv0,&impv,&impvn,&mapd,&cntrlv,&seed);
data allwv0;
    set allwv0;
    array t1{*} &impv;
    array t2{*} &impvn;
    do i=1 to dim(t1);
        t1{i}=t2{i};
        end;
    drop i &impvn;
run;



data hlth3;
    input var1 var2 var3 var4 var5 hlth3;
    cards;
    1 0 0 0 0 1
    0 1 0 0 0 2
    0 0 1 0 0 3
    0 0 0 1 0 4
    0 0 0 0 1 5
    1 1 1 1 1 6
        ;
run;
data hlthch3;
    input var1 var2 var3 hlthch3;
    cards;
    1 0 0 1
    0 1 0 2
    0 0 1 3
    1 1 1 4
        ;
run;
data numadl3;
    input var0 var1 var2 var3 var4 var5 var6 numadl3;
    cards;
    1 0 0 0 0 0 0 0
    0 1 0 0 0 0 0 1
    0 0 1 0 0 0 0 2
    0 0 0 1 0 0 0 3
    0 0 0 0 1 0 0 4
    0 0 0 0 0 1 0 5
    0 0 0 0 0 0 1 6
    1 1 1 1 1 1 1 7
        ;
run;
data numiadl3;
    input var0 var1 var2 var3 var4 var5 numiadl3;
    cards;
    1 0 0 0 0 0 0
    0 1 0 0 0 0 1
    0 0 1 0 0 0 2
    0 0 0 1 0 0 3
    0 0 0 0 1 0 4
    0 0 0 0 0 1 5
    1 1 1 1 1 1 6
        ;
run;

%let seed=10;
%let p=;
%let cntrlv=
    &p.cancer&w
    &p.heart&w
    &p.stroke&w
    &p.psych&w
    &p.fall&w
    &p.hipfrc&w
    &p.incont&w
    &p.depres&w
    ;
%let impv=hlth3 hlthch3;
%let impvn=_hlth3 _hlthch3;
%let mapd=hlth3 hlthch3;


%impcat(allwv0,&impv,&impvn,&mapd,&cntrlv,&seed);
data allwv0;
    set allwv0;
    array t1{*} &impv;
    array t2{*} &impvn;
    do i=1 to dim(t1);
        t1{i}=t2{i};
        end;
    drop i &impvn ;
run;


%let seed=11;
%let impv=numadl3 numiadl3;
%let impvn=_numadl3 _numiadl3;
%let mapd=numadl3 numiadl3;
%impcat(allwv0,&impv,&impvn,&mapd,&cntrlv,&seed);

%let noexit=highbp3 arthrt3 diabet3 psych3 depres3 smoknow3 drnknow3 hlth3 hlthch3;
data allwv0;
    set allwv0;
    array t1{*} &impv;
    array t2{*} &impvn;
    do i=1 to dim(t1);
        t1{i}=t2{i};
        end;
    drop i &impvn;

    array t3{*} &noexit;
    do i=1 to dim(t3);
        if exitw3=1 then t3{i}=.;
        end;

    if hlthch3 ne . then do;
        hlthbet3=(hlthch3=1);
        hlthsam3=(hlthch3=2);
        hlthwrs3=(hlthch3=3);
        end;
    drop hlthch3;    
run;

data allwv;
    set allwv0 allwv1;
run;



