/*****************************************************************/
/* FILE:        	impcat.sas                               */
/* PROJECT: 		Healthy, Wealthy, & Wise (AHEAD Data)    */
/* FACULTY:		Dan McFadden                             */
/* AUTHOR:		Tiago Ribeiro                            */
/* LAST UPDATE:		Jan 2003                                 */
/* PROGRAM DESC:	Runs categorical asset imputation        */
/* CONTACT:             tribeiro@econ.berkeley.edu               */
/*****************************************************************/
%include "~/ribeiro/datagen/header.inc";

%include "impcat_macro.sas";
/*
proc contents data=local8.w1assets; run;
proc contents data=track.track; run;
proc contents data=asstcat.c_hous1; run;
proc print data=asstcat.c_hous1; run;
*/

data track;
    set track.track;
    if study in(11,12,13);
    _dsubhh=dsubhh+0;
    _fsubhh=fsubhh+0;
    drop dsubhh fsubhh;
run;
data track;
    set track;
    rename
        _dsubhh=dsubhh
        _fsubhh=fsubhh;
run;


%let id=bppn;
data spouse;
    set track;
    hhidpn=hhid*1000+&id;
    keep hhidpn;
run;
%merge(track,track,spouse,hhidpn);
data track;
    set track;
    nhh&id=in1+in2;
    label nhh&id ="num of hh members based on &id";
    if in1;
    drop in1 in2;
run;
%let id=dppn;
data spouse;
    set track;
    hhidpn=hhid*1000+&id;
    keep hhidpn;
run;
%merge(track,track,spouse,hhidpn);
data track;
    set track;
    nhh&id=in1+in2;
    label nhh&id ="num of hh members based on &id";
    if in1;
    drop in1 in2;
run;
%let id=fppn;
data spouse;
    set track;
    hhidpn=hhid*1000+&id;
    keep hhidpn;
run;
%merge(track,track,spouse,hhidpn);
data track;
    set track;
    nhh&id=in1+in2;
    label nhh&id ="num of hh members based on &id";
    if in1;
    drop in1 in2;
run;

data wv1;
    set track;
    if inw1;
    keep hhid nhhbppn bfinr bproxy;
run;
proc sort data=wv1; by hhid descending bfinr;    
data wv1;
    set wv1;
    by hhid descending bfinr;
    if first.hhid or (first.hhid=0 and bfinr=1);
run;
proc sort data=wv1(drop=bfinr) nodupkey out=wv1; by hhid bproxy;
*%count(wv1,hhid,nhh2);
data wv1; set wv1; if bproxy=1 then bproxy=5; run;
    
data wv2;
    set track;
    if inw2 or exitw2;
    keep hhid dsubhh nhhdppn dfinr dproxy;
run;
proc sort data=wv2; by hhid dsubhh descending dfinr;    
data wv2;
    set wv2;
    by hhid dsubhh descending dfinr;
    if first.dsubhh or (first.dsubhh=0 and dfinr=1);
run;
proc sort data=wv2(drop=dfinr) nodupkey; by hhid dsubhh dproxy;
*%count(wv2,hhid dsubhh,nhh2);

data wv3;
    set track;
    if inw3 or exitw3;
    keep hhid dsubhh fsubhh nhhfppn ffinr fproxy;
run;
proc sort data=wv3; by hhid fsubhh descending ffinr;    
data wv3;
    set wv3;
    by hhid fsubhh descending ffinr;
    if first.fsubhh or (first.fsubhh=0 and ffinr=1);
run;
proc sort data=wv3(drop=ffinr) nodupkey; by hhid fsubhh fproxy;
*%count(wv3,hhid fsubhh,nhh2);
proc sort data=wv3 nodupkey; by hhid fsubhh;


*proc printto log='impcat1.log' print='impcat1.lst' new;
*%include 'impcat1.sas';
*proc printto log='impcat2.log' print='impcat2.lst' new; run;
*%include 'impcat2.sas';
proc printto log='impcat3.log' print='impcat3.lst' new;
%include 'impcat3.sas';







