

% AUTHOR  : Tiago Ribeiro
% FACULTY : Dan McFadden
% PROJECT : AHEAD
% CONTENTS: Imputes months at risk for deceased respondents
% LAST MODIFIED: 02/28/02

 

%---------------------------------;
%  Read Data                      ;
%---------------------------------;
data=dlmread('months.csv',',');
month1=data(:,2);
month2=data(:,3);
month3=data(:,4);
tdied2=data(:,5);
tdied3=data(:,6);
agem1=data(:,7); 
monthd2=data(:,8); 
monthd3=data(:,9); 

[t1,t2,t3]=unique([tdied2 tdied3],'rows');
t1
%monthd3(find(t3==3 & monthd3>0))=-9;
    
name1={'month' 'dono' 'need i'};
%---------------------------------;
%  Define functions               ;
%---------------------------------;

logit=inline('sum(log(1+exp(-(X*b)))+(1-z).*(X*b))','b','X','z');
probit=inline('-sum(log(normcdf(y.*(X*b))+(normcdf(y.*(X*b))==0)*1e-100))','b','X','y');

options=optimset(...
    'Display','off',...
    'Diagnostics','off',...
    'GradObj','off',...
    'Hessian','off',...
    'LargeScale','off',...
    'DerivativeCheck','off',...
    'MaxIter',300,...
    'HessUpdate','bfgs',...
    'MaxFunEvals',100);

%    'TolFun',1e-3,...
%    'TolX',1e-3,...

    
%%%%%%%%%%%%%%%%%%%%%%%%%%;
% Wave 2 month imputations;
%%%%%%%%%%%%%%%%%%%%%%%%%%;

%----------------;
%Initiallize vars;
%----------------;

m1=month1;
z1=(month1<1130 & tdied2==0);
g1=zeros(size(month1));
m2=zeros(size(month1));
one=ones(size(month1));

%-----------------------;
%Mixture model for W1-W2;
%-----------------------;

s=find(month2~=-9 & tdied2==0);
ns=find(month2==-9 & tdied2==0);
d=find(month2~=-9 & tdied2==1);
nd=find(month2==-9 & tdied2==1);

% EM algorithm ;
%--------------;

for i=[1:10];
mu1=sum(    z1(s).*month2(s))/sum(z1(s));
mu2=sum((1-z1(s)).*month2(s))/sum(1-z1(s));
s1=sum(    z1(s).*(month2(s)-mu1).^2)/sum(z1(s));
s2=sum((1-z1(s)).*(month2(s)-mu2).^2)/sum(1-z1(s));

p1=sum(z1(s))/size(z1(s),1);

co=[0 0]'; 
[co]=fminunc(logit,co,options,[one(s) month1(s)],z1(s));
xb=[one month1]*co;
p=1./(1+exp(-xb));

zh=1./(1+sqrt(s1/s2)*exp((month2(s)-mu1).^2/s1/2-(month2(s)-mu2).^2/s2/2).*(1-p(s))./p(s));
z1(s)=zh;
%z1(d)=0;
res(i,:)=[mu1 mu2 s1 s2 p1];
end;
disp(res)

% Print groups ;
%--------------;
res=[];
n=0;
for j=min(month1):max(month1);
n=n+1;
sam=find(month1==j & tdied2==0 & month2~=-9);
res(n,:)=[j min(z1(sam)) mean(z1(sam)) max(z1(sam))];
end;
num2cell(res)
   
% Impute missing and not died ;
%-----------------------------;

z1(ns)=p(ns);
z1(d)=p(d);
z1(nd)=p(nd);

rand('state',12);
g1=(rand(size(month1))<z1);

s_1 =find(month2~=-9 & tdied2==0 & g1==1);
ns_1=find(month2==-9             & g1==1);
s_2 =find(month2~=-9 & tdied2==0 & g1==0);
ns_2=find(month2==-9             & g1==0);

die1 =find(month2~=-9 & tdied2==1 & g1==0);
die2 =find(month2~=-9 & tdied2==1 & g1==1);
die  =find(month2~=-9 & tdied2==1        );

r1=ceil(rand(size(ns_1))*size(s_1,1));
r2=ceil(rand(size(ns_2))*size(s_2,1));

m2(s_1)=month2(s_1);
m2(ns_1)=month2(s_1(r1));
m2(s_2)=month2(s_2);
m2(ns_2)=month2(s_2(r2));

% Impute month of death       ;
%-----------------------------;

res=[];
n=0;
for j=min(month2(find(month2>0))):max(month2(find(month2>0)));
n=n+1;
dono =find(tdied2==1 & month2==j & monthd2~=-9);
needi=find(tdied2==1 & month2==j & monthd2==-9);
res(n,:)=[j size(dono,1) size(needi,1)] ;

if isempty(needi)==0;
r=ceil(rand(size(needi))*size(dono,1));
monthd2(needi)=monthd2(dono(r));
end;

end;
disp([name1;num2cell(res)])
res=[];

dothis=0;
if dothis==1;
% Delay model for deceased by g ;
%-----------------------------;

sg1=find(g1==0);
X=[ones(size(sg1)) log(m2(sg1)-m1(sg1)) ...
       (agem1(sg1)/12>=75 & agem1(sg1)/12<80)...
       (agem1(sg1)/12>=80 & agem1(sg1)/12<85)...
       (agem1(sg1)/12>=85 & agem1(sg1)/12<90)];
X1=X;X2=X;X3=X;
X1(:,2)=log(12);
X2(:,2)=log(24);
X3(:,2)=log(36);

t20=min(m2(s));
m_2=month2(die1)-t20;
md2=(monthd2(die1)-t20).*((monthd2(die1)-t20)>0);
rand('state',23);
r=rand(size(md2));

clear outp; 
n=0;
%for dL=-40e-1:1e-1:-20e-1;
%for dL=-2.4:.01:-2.4;
dL=-.625;
n=n+1;

C0=exp(-dL*md2)-exp(-dL*m_2);
p0=exp(-dL*md2);
t=-log(-r.*C0+p0)/dL;
m2(die1)=t+t20;
m12=m2(sg1)-m1(sg1);
X(:,2)=log(m12);

co=[0 0 0 0 0]';
[co,fval]=fminunc(probit,co,options,X,2*tdied2(sg1)-1);

pd1=normcdf(X1*co);
pd2=normcdf(X*co);
pd3=normcdf(X3*co);
mpd1=mean(pd1);
mpd2=mean(pd2);
mpd3=mean(pd3);

outp(n,1:11)=[dL co'...
mean((((pd1-(1-(1-pd2).^(12./m12))).^2+(pd3-(1-(1-pd2).^(36./m12))).^2)/3).^(1/2))...
(((mpd1-(1-(1-mpd2).^(1/2))).^2+(mpd3-(1-(1-mpd2).^(3/2))).^2)/3).^(1/2)...
mean([pd1 pd2 pd3])];

%end;

disp(outp)

sg1=find(g1==1);
X=[ones(size(sg1)) log(m2(sg1)-m1(sg1)) ...
       (agem1(sg1)/12>=75 & agem1(sg1)/12<80)...
       (agem1(sg1)/12>=80 & agem1(sg1)/12<85)...
       (agem1(sg1)/12>=85 & agem1(sg1)/12<90)];
X1=X;X2=X;X3=X;
X1(:,2)=log(12);
X2(:,2)=log(24);
X3(:,2)=log(36);

t20=min(m2(s));
m_2=month2(die2)-t20;
md2=(monthd2(die2)-t20).*((monthd2(die2)-t20)>0);
rand('state',34);
r=rand(size(md2));
 
clear outp;
n=0;
%for dL=-8e-1:25e-3:-3e-1;
%for dL=-55e-2:25e-3:-55e-2;
dL=-.625;
n=n+1;

C0=exp(-dL*md2)-exp(-dL*(m_2-2));
p0=exp(-dL*md2);
t=-log(-r.*C0+p0)/dL;
m2(die2)=t+t20;
m12=m2(sg1)-m1(sg1);
X(:,2)=log(m12);

co=[0 0 0 0 0]';
[co,fval]=fminunc(probit,co,options,X,2*tdied2(sg1)-1);

pd1=normcdf(X1*co);
pd2=normcdf(X*co);
pd3=normcdf(X3*co);
mpd1=mean(pd1);
mpd2=mean(pd2);
mpd3=mean(pd3);

outp(n,1:11)=[dL co'...
mean((((pd1-(1-(1-pd2).^(12./m12))).^2+(pd3-(1-(1-pd2).^(36./m12))).^2)/3).^(1/2))...
(((mpd1-(1-(1-mpd2).^(1/2))).^2+(mpd3-(1-(1-mpd2).^(3/2))).^2)/3).^(1/2)...
mean([pd1 pd2 pd3])];

%end;
disp(outp)
end;

dothis=1;
if dothis==1;
% Delay model for deceased - all ;
%--------------------------------;

X=[ones(size(agem1)) log(m2-m1) ...
       (agem1/12>=75 & agem1/12<80)...
       (agem1/12>=80 & agem1/12<85)...
       (agem1/12>=85 & agem1/12<90)];
X1=X;X2=X;X3=X;
X1(:,2)=log(12);
X2(:,2)=log(24);
X3(:,2)=log(36);

t20=min(m2(s));
m_2=month2(die)-t20;
md2=(monthd2(die)-t20).*((monthd2(die)-t20)>0);
rand('state',23);
r=rand(size(md2));

clear outp; 
n=0;
%for dL=-40e-1:1e-1:-20e-1;
%for dL=-2.4:.01:-2.4;
dL=-.625;
n=n+1;

C0=exp(-dL*md2)-exp(-dL*m_2);
p0=exp(-dL*md2);
t=-log(-r.*C0+p0)/dL;
m2(die)=t+t20;
m12=m2-m1;
X(:,2)=log(m12);

co=[0 0 0 0 0]';
[co,fval]=fminunc(probit,co,options,X,2*tdied2-1);

pd1=normcdf(X1*co);
pd2=normcdf(X*co);
pd3=normcdf(X3*co);
mpd1=mean(pd1);
mpd2=mean(pd2);
mpd3=mean(pd3);

outp(n,1:11)=[dL co'...
mean((((pd1-(1-(1-pd2).^(12./m12))).^2+(pd3-(1-(1-pd2).^(36./m12))).^2)/3).^(1/2))...
(((mpd1-(1-(1-mpd2).^(1/2))).^2+(mpd3-(1-(1-mpd2).^(3/2))).^2)/3).^(1/2)...
mean([pd1 pd2 pd3])];

%end;

end;


% Impute month of death       ;
%-----------------------------;
res=[];
n=0;
for j=min(month2(find(month2>0))):max(month2(find(month2>0)));
n=n+1;
dono =find(tdied2==1 & month2~=-9 & monthd2~=-9 & round(m2)==j);
needi=find(tdied2==1 & month2==-9 & monthd2==-9 & round(m2)==j);
res(n,:)=[j size(dono,1) size(needi,1)] ;
if isempty(needi)==0;
r=ceil(rand(size(needi))*size(dono,1));
monthd2(needi)=monthd2(dono(r));
end;
end;
disp([name1;num2cell(res)])
res=[];

%%%%%%%%%%%%%%%%%%%%%%%%%%;
% Wave 3 month imputations;
%%%%%%%%%%%%%%%%%%%%%%%%%%;

agem2=agem1+m2-m1;

%----------------;
%Initiallize vars;
%----------------;

z1=(month3<1180 & tdied2==0 & tdied3==0);
g2=zeros(size(month1));
m3=zeros(size(month1));

%-----------------------;
%Mixture model for W2-W3;
%-----------------------;

s= find(month3~=-9 & tdied2==0 & tdied3==0);
ns=find(month3==-9 & tdied2==0 & tdied3==0);
d= find(month3~=-9 & tdied2==0 & tdied3==1);
nd=find(month3==-9 & tdied2==0 & tdied3==1);


% EM algorithm ;
%--------------;

for i=[1:20];
mu1=sum(    z1(s).*month3(s))/sum(z1(s));
mu2=sum((1-z1(s)).*month3(s))/sum(1-z1(s));
s1=sum(    z1(s).*(month3(s)-mu1).^2)/sum(z1(s));
s2=sum((1-z1(s)).*(month3(s)-mu2).^2)/sum(1-z1(s));

p1=sum(z1(s))/size(z1(s),1);

co=[0 0]'; 
[co]=fminunc(logit,co,options,[one(s) m2(s)],z1(s));
xb=[one m2]*co;
p=1./(1+exp(-xb));

zh=1./(1+sqrt(s1/s2)*exp((month3(s)-mu1).^2/s1/2-(month3(s)-mu2).^2/s2/2).*(1-p(s))./p(s));
z1(s)=zh;
%z1(d)=0;
res(i,:)=[mu1 mu2 s1 s2 p1];
end;
num2cell(res)
res=[];

% Print groups ;
%--------------;

res=[];
n=0;
for j=min(m2):max(m2);
n=n+1;
sam=find(m2==j & tdied2==0 & tdied3==0 & month3~=-9);
res(n,:)=[min(z1(sam)) mean(z1(sam)) max(z1(sam))];
end;
num2cell(res)
    
% Impute missing and not died ;
%-----------------------------;
   
z1(ns)=p(ns);
z1(d)=p(d);
z1(nd)=p(nd);

rand('state',45);
g2=(rand(size(month1))<z1);

s_1 =find(month3~=-9 & tdied2==0 & tdied3==0 & g2==1);
ns_1=find(month3==-9 & tdied2==0             & g2==1);
s_2 =find(month3~=-9 & tdied2==0 & tdied3==0 & g2==0);
ns_2=find(month3==-9 & tdied2==0             & g2==0);

die1 =find(month3~=-9 & tdied2==0 & tdied3==1 & g2==0);
die2 =find(month3~=-9 & tdied2==0 & tdied3==1 & g2==1);

r1=ceil(rand(size(ns_1))*size(s_1,1));
r2=ceil(rand(size(ns_2))*size(s_2,1));

m3(s_1)=month3(s_1);
m3(ns_1)=month3(s_1(r1));
m3(s_2)=month3(s_2);
m3(ns_2)=month3(s_2(r2));



% Impute month of death       ;
%-----------------------------;
res=[];
n=0;
for j=min(month3(find(month3>0))):max(month3(find(month3>0)));
n=n+1;
dono =find(tdied3==1 & month3==j & monthd3~=-9);
needi=find(tdied3==1 & month3==j & monthd3==-9);
res(n,:)=[j size(dono,1) size(needi,1)] ;
if isempty(needi)==0;
r=ceil(rand(size(needi))*size(dono,1));
monthd3(needi)=monthd3(dono(r));
end;
end;
disp([name1;num2cell(res)])
res=[];    

% Delay model for deceased    ;
%-----------------------------;

die0 =find(month3~=-9 & tdied2==0 & tdied3==1);
 
sg1=find(tdied2==0);
X=[ones(size(sg1)) log(m3(sg1)-m2(sg1)) ...
       (agem2(sg1)/12>=75 & agem2(sg1)/12<80)...
       (agem2(sg1)/12>=80 & agem2(sg1)/12<85)...
       (agem2(sg1)/12>=85 & agem2(sg1)/12<90)];
X1=X;X2=X;X3=X;
X1(:,2)=log(12);
X2(:,2)=log(24);
X3(:,2)=log(36);


t30=min(m3(s));
m_3=month3(die0)-t30;
md3=(monthd3(die0)-t30).*((monthd3(die0)-t30)>0);
md3(find(md3==73))=7;
rand('state',56);
r=rand(size(md3));
 
clear outp;
n=0;
%for dL=-2e0:1e-1:-1e-1;
%for dL=-14e-1:25e-3:-14e-1;
dL=-.2;
n=n+1;

C0=exp(-dL*md3)-exp(-dL*(m_3-1.5));
p0=exp(-dL*md3);
t=-log(-r.*C0+p0)/dL;
m3(die0)=t+t30;
m23=m3(sg1)-m2(sg1);
X(:,2)=log(m23);

co=[0 0 0 0 0]';
[co,fval]=fminunc(probit,co,options,X,2*tdied3(sg1)-1);

pd1=normcdf(X1*co);
pd2=normcdf(X*co);
pd3=normcdf(X3*co);
mpd1=mean(pd1);
mpd2=mean(pd2);
mpd3=mean(pd3);

outp(n,1:11)=[dL co'...
mean((((pd1-(1-(1-pd2).^(12./m23))).^2+(pd3-(1-(1-pd2).^(36./m23))).^2)/3).^(1/2))...
(((mpd1-(1-(1-mpd2).^(1/2))).^2+(mpd3-(1-(1-mpd2).^(3/2))).^2)/3).^(1/2)...
mean([pd1 pd2 pd3])];

%end;

disp(outp)


% Impute month of death       ;
%-----------------------------;

res=[];
n=0;
for j=min(month3(find(month3>0))):max(month3(find(month3>0)));
n=n+1;
dono =find(tdied3==1 & month3~=-9 & monthd3~=-9 & round(m3)==j);
if isempty(dono)==1;
dono =find(tdied3==1 & month3~=-9 & monthd3~=-9 & round(m3)==j-2);
end;
needi=find(tdied3==1 & month3==-9 & monthd3==-9 & round(m3)==j);
res(n,:)=[j size(dono,1) size(needi,1)] ;
if isempty(needi)==0;
r=ceil(rand(size(needi))*size(dono,1));
monthd3(needi)=monthd3(dono(r));
end;
end;
disp([name1;num2cell(res)])
res=[];    

m12=m2-m1;
m23=m3-m2;
agem3=agem2+m23;

stats

dlmwrite('m_impted.csv',[data(:,1) m1 m2 m3 m12 m23 monthd2 monthd3 agem2 agem3 g1 g2],',');



